##############################################################################
#
#    Copyright (C) 2019 Eynes - Ingenieria del software (www.eynes.com.ar)
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as published
#    by the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

from odoo import fields, models, tools, api
from odoo.addons import decimal_precision as dp 
from odoo.exceptions import UserError, ValidationError


class ProductProduct(models.Model):
    _inherit = 'product.product'

    standard_price = fields.Float(
        'Cost', company_dependent=False,
        digits=dp.get_precision('Product Price'),
        groups="base.group_user",
        help = "Cost used for stock valuation in standard price and as a first price to set in average/fifo. "
        "Also used as a base price for pricelists. "
        "Expressed in the default unit of measure of the product."
    )    


class ProductProduct(models.Model):
    _inherit = 'product.product'
    def get_rate(self):
       
        try:
            rate = self.product_tmpl_id.currency_id.rate
        except:
            import wdb;wdb.set_trace()
        return {"rate": rate}
class ProductTemplate(models.Model):
    _inherit = 'product.template'

    name = fields.Char(translate=False)
    charged_ml = fields.Boolean('Charged in Mercado Libre')
    maker_id = fields.Many2one('res.partner', string='Maker')

    

    def _compute_nbr_reordering_rules(self):
        res = {k: {'nbr_reordering_rules': 0, 'reordering_min_qty': 0, 'reordering_max_qty': 0} for k in self.ids}
        product_data = self.env['stock.warehouse.orderpoint'].read_group([('product_id.product_tmpl_id', 'in', self.ids)], ['product_id', 'product_min_qty', 'product_max_qty'], ['product_id'])
        for data in product_data:
            product = self.env['product.product'].browse([data['product_id'][0]])
            product_tmpl_id = product.product_tmpl_id.id
            res[product_tmpl_id]['nbr_reordering_rules'] += int(data['product_id_count'])
            res[product_tmpl_id]['reordering_min_qty'] = data['product_min_qty']
            res[product_tmpl_id]['reordering_max_qty'] = data['product_max_qty']
        for template in self:
            if template.id in res:
                template.nbr_reordering_rules = res[template.id]['nbr_reordering_rules']
                template.reordering_min_qty = res[template.id]['reordering_min_qty']
                template.reordering_max_qty = res[template.id]['reordering_max_qty']


class ProductSupplierInfo(models.Model):
    _inherit = 'product.supplierinfo'

    company_id = fields.Many2one(default=False)

    # Dice que no existe una column 'name'

    # def _auto_init(self):
    #     """ UNIQUE on supplier-product.template-product_code"""
    #     result = super()._auto_init()
    #     tools.create_unique_index(self._cr, 'psi_supplier_code_product_unique_index',
    #             self._table, ['name', 'product_tmpl_id', "COALESCE(product_code,'-1')"])
    #     return result


class AccountInvoiceReport(models.Model):
    _inherit = 'account.invoice.report'

    maker_id  = fields.Many2one('res.partner', string='Maker')

    def _select(self):
        res = super(AccountInvoiceReport, self)._select()
        return  res + ", template.maker_id as maker_id"

    def _sub_select(self):
        return super(AccountInvoiceReport, self)._sub_select() + ", pr.maker_id AS maker_id"

    def _group_by(self):
        return super(AccountInvoiceReport, self)._group_by() + ", pr.maker_id "
