/** @odoo-module */

import { patch } from "@web/core/utils/patch";
import { PosStore } from "@point_of_sale/app/store/pos_store";
import { Product } from "@point_of_sale/app/store/models";

patch(PosStore.prototype, {
    async _loadProductProduct(products) {

        const picking_type_id = this.picking_type.id 

        const pickingType = await this._getStockPickingType(picking_type_id);
        const stock_location_id = pickingType.default_location_src_id[0]

        const productMap = {};
        const productTemplateMap = {};
    
        const productTemplateIds = products.map(product => product.product_tmpl_id[0]);
        const supplierInfoData = await this._getProductSupplierinfo(productTemplateIds);

        const productIds = products.map(product => product.id);
        const stockData = await this._getProductStock(productIds, stock_location_id);
    
        const modelProducts = products.map((product) => {
            product.pos = this;
            product.env = this.env;
            product.applicablePricelistItems = {};
            product.supplier_infos = supplierInfoData[product.product_tmpl_id[0]] || [];
            product.stock_available = stockData[product.id] || 0;
            productMap[product.id] = product;
            productTemplateMap[product.product_tmpl_id[0]] = (
                productTemplateMap[product.product_tmpl_id[0]] || []
            ).concat(product);
            return new Product(product);
        });
    
        for (const pricelist of this.pricelists) {
            for (const pricelistItem of pricelist.items) {
                if (pricelistItem.product_id) {
                    const product_id = pricelistItem.product_id[0];
                    const correspondingProduct = productMap[product_id];
                    if (correspondingProduct) {
                        this._assignApplicableItems(pricelist, correspondingProduct, pricelistItem);
                    }
                } else if (pricelistItem.product_tmpl_id) {
                    const product_tmpl_id = pricelistItem.product_tmpl_id[0];
                    const correspondingProducts = productTemplateMap[product_tmpl_id];
                    for (const correspondingProduct of correspondingProducts || []) {
                        this._assignApplicableItems(pricelist, correspondingProduct, pricelistItem);
                    }
                } else {
                    for (const correspondingProduct of products) {
                        this._assignApplicableItems(pricelist, correspondingProduct, pricelistItem);
                    }
                }
            }
        }
        this.db.add_products(modelProducts);
    },

    async _getProductSupplierinfo(productTemplateIds) {
        const supplierInfos = await this.orm.call(
            'product.supplierinfo',
            'search_read',
            [],
            {
                domain: [['product_tmpl_id', 'in', productTemplateIds]],
                fields: ['product_code', 'product_tmpl_id'],
            }
        );
    
        const supplierInfoMap = {};
        for (const info of supplierInfos) {
            if (!supplierInfoMap[info.product_tmpl_id[0]]) {
                supplierInfoMap[info.product_tmpl_id[0]] = [];
            }
            supplierInfoMap[info.product_tmpl_id[0]].push(info);
        }
        return supplierInfoMap;
    },

    async _getStockPickingType(picking_type_id) {
        const pickingType = await this.orm.call(
            'stock.picking.type',
            'search_read',
            [],
            {
                domain: [['id', '=', picking_type_id]],
                fields: ['id', 'name', 'code', 'default_location_src_id', 'default_location_dest_id'],
            }
        );
        return pickingType.length ? pickingType[0] : null;
    },

    async _getProductStock(productIds, location_id) {
        const quants = await this.orm.call(
            'stock.quant',
            'search_read',
            [],
            {
                domain: [['product_id', 'in', productIds], ['location_id', '=', location_id]],
                fields: ['product_id', 'quantity'],
            }
        );

        const stockMap = {};
        for (const quant of quants) {
            stockMap[quant.product_id[0]] = quant.quantity;
        }
        return stockMap;
    },

});
