/** @odoo-module */

import { useState } from "@odoo/owl";
import { patch } from "@web/core/utils/patch";
import { ProductCard } from "@point_of_sale/app/generic_components/product_card/product_card";
import { jsonrpc } from "@web/core/network/rpc_service"

patch(ProductCard.prototype, {
    setup() {
        this.priceInARS = useState({value:null}); // Valor por defecto
        this.fetchPriceARS();
        super.setup(...arguments); // Llamar al setup original si existe
        
    },

    async fetchPriceARS() {
        try {
            const data = await jsonrpc("/web/dataset/call_kw/product.product/get_rate", {
                model: "product.product",
                method: "get_rate",
                args: [this.props.productId],
                kwargs: {},
            });
            if (data && data.rate) {
                const numericPrice = parseFloat(this.props.price.replace(/[^0-9,.-]/g, '').replace('.', '').replace(',', '.'));
                const priceARS = numericPrice * data.rate;
                this.priceInARS.value = `$ ${priceARS.toFixed(2)}`; // Guardar la tasa de cambio
                this.render(); // Refrescar el componente
            }
        } catch (error) {
            console.error("Error obteniendo:", error);
        }
    },

});

